==> filehandler-1.0.0.tar.gz: lib/filehandler.dart <==
import 'dart:io';
import 'package:filehandler/utils/simplefile.dart';
import 'package:filesystem_picker/filesystem_picker.dart';
import 'package:flutter/material.dart';
import 'package:folder_file_saver/folder_file_saver.dart';

class FileHandler {
  static const INTERNAL_DIR = "storage/emulated/0/";
  Directory fftDir() => Directory(INTERNAL_DIR + folderName);
  String folderName;
  String ext;

  FileHandler({this.folderName = "", this.ext = ".txt"});

  Future<bool> _checkAppDir() async {
    try {
      final resultPermission = await FolderFileSaver.requestPermission();
      // 0 permission is PERMISSION_GRANTED
      if (resultPermission == 0) {
        if ((await fftDir().exists()) == false) {
          await fftDir().create();
        }
        return true;
      }
    } catch (e) {}
    return false;
  }

  Future<SimpleFile> openFile(BuildContext context) async {
    var result = await _checkAppDir();
    if (result == false) return null;

    var path = await FilesystemPicker.open(
            title: 'Open file',
            context: context,
            rootDirectory: fftDir(),
            fsType: FilesystemType.file,
            folderIconColor: Colors.blue,
            allowedExtensions: [this.ext],
            fileTileSelectMode: FileTileSelectMode.wholeTile) ??
        null;

    String content;
    if (path != null && path.isNotEmpty) {
      var file = File(path);
      if (await file.exists()) {
        try {
          content = await file.readAsString();
        } catch (e) {
          return null;
        }
      }
    } else
      return null;

    return (content == null || content.isEmpty)
        ? null
        : SimpleFile(path.split('/').last.replaceAll(this.ext, ""), content);
  }

  Future<bool> saveFile(String filename, String data) async {
    var result = await _checkAppDir();
    if (result == false) return false;

    try {
      var dir = fftDir().path;
      var divChar = folderName.isEmpty ? "" : "/";
      var file = File("$dir$divChar$filename$ext");
      return await _updateFileContent(file, data);
    } catch (e) {
      return false;
    }
  }

  static Future<bool> _updateFileContent(File file, String content) async {
    if (!(await file.exists())) {
      try {
        var result = await file.create();
        if (result == null) return false;
      } catch (e) {
        return false;
      }
    }

    var result = await file.writeAsString(content);
    if (result == null) return false;

    return true;
  }
}

==> filehandler-1.0.1.tar.gz: lib/filehandler.dart <==
import 'dart:io';
import 'package:filehandler/utils/simplefile.dart';
import 'package:filesystem_picker/filesystem_picker.dart';
import 'package:flutter/material.dart';
import 'package:folder_file_saver/folder_file_saver.dart';

class FileHandler {
  static const INTERNAL_DIR = "storage/emulated/0/";
  Directory fftDir() => Directory(INTERNAL_DIR + folderName);
  String folderName;
  String ext;

  FileHandler({this.folderName = "", this.ext = ".txt"});

  Future<SimpleFile> openFile(BuildContext context) async {
    var result = await _checkAppDir();
    if (result == false) return null;

    var path = await FilesystemPicker.open(
            title: 'Open file',
            context: context,
            rootDirectory: fftDir(),
            fsType: FilesystemType.file,
            folderIconColor: Colors.blue,
            allowedExtensions: [this.ext],
            fileTileSelectMode: FileTileSelectMode.wholeTile) ??
        null;

    String content;
    if (path != null && path.isNotEmpty) {
      var file = File(path);
      if (await file.exists()) {
        try {
          content = await file.readAsString();
        } catch (e) {
          return null;
        }
      }
    } else
      return null;

    return (content == null || content.isEmpty)
        ? null
        : SimpleFile(path.split('/').last.replaceAll(this.ext, ""), content);
  }

  Future<bool> saveFile(String filename, String data) async {
    if (filename.isEmpty) return false;

    var result = await _checkAppDir();
    if (result == false) return false;

    try {
      var dir = fftDir().path;
      var divChar = folderName.isEmpty ? "" : "/";
      var file = File("$dir$divChar$filename$ext");
      return await _updateFileContent(file, data);
    } catch (e) {
      return false;
    }
  }

  Future<bool> _updateFileContent(File file, String content) async {
    if (!(await file.exists())) {
      try {
        var result = await file.create();
        if (result == null) return false;
      } catch (e) {
        return false;
      }
    }

    var result = await file.writeAsString(content);
    if (result == null) return false;

    return true;
  }

  Future<bool> _checkAppDir() async {
    try {
      final resultPermission = await FolderFileSaver.requestPermission();
      // 0 permission is PERMISSION_GRANTED
      if (resultPermission == 0) {
        if ((await fftDir().exists()) == false) {
          await fftDir().create();
        }
        return true;
      }
    } catch (e) {}
    return false;
  }
}
